EasyExtend.langlets.p4d.p4dutils

Package EasyExtend :: Package langlets :: Package p4d :: Module p4dutils |
[hide private]
[frames] | no frames]

# Module p4dutils

Classes | [hide private]
| TagIsKeywordWarning
| pprinter
| p4dprinter

Functions | [hide private]
ignore_whitespace(S) |
softrstrip(S) |
shave(text) If we have a text of following shape:: |
indentk(text, k, lbra=`'````'`, rbra=`'````'`) |

Function Details | [hide private]

### shave(text) |
    If we have a text of following shape::

        |   foo
        |     bar
        |  baz

    it will be left-aligned:

        | foo
        |   bar
        |baz